<?php
/*
Plugin Name: G3 Avatar
Plugin URI: http://www.g3code.com/
Description: Display a Gravatar, it's super simple!
Version: 0.9
Author: Grabek
Author URI: http://www.g3code.com/
*/

if (!class_exists('G3Avatar')) {
	class G3Avatar{
		var $ver="0.9";
		var $alt="G3 Avatar v.0.9";
		var $default_gravatar_url='http://www.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536';
		var $default_gravatar_size=80;
		var $settings_link_slug='g3_avatar_settings';
		var $db_options_name='g3_avatar_options';

		function G3Avatar(){
			add_action('admin_head', array(&$this, 'add_admin_head'));
			add_action('admin_menu', array(&$this, 'add_admin_menu'));
			add_filter('plugin_action_links', array(&$this, 'add_plugin_settings_link'), 10, 2 );
		}
		/*
			build admin interface
		*/
		function add_plugin_settings_link($links, $file) {
			$this_plugin = plugin_basename(__FILE__);

			if ($file == $this_plugin){
				$slink = '<a href="admin.php?page='.$this->settings_link_slug.'">'.__("Settings").'</a>';
				array_unshift($links, $slink);
			}
			return $links;
		}
		function add_admin_head(){
			echo('<link rel="stylesheet" href="'.plugins_url('g3_avatar/g3admin.css').'" type="text/css" media="screen" />');
		}
		function add_admin_menu(){
			add_options_page('G3 Avatar', 'G3 Avatar Settings', 10, $this->settings_link_slug, array(&$this,'admin_options_page_constructor'));
		}
		/*
			activate, deactivate, update
		*/
		function activate(){
			if ($opt=get_option($this->db_options_name)){
				if (version_compare($this->ver,$opt['version'])==1){
					$this->update();
				}
			}else{
				$this->install();
			}
		}
		function update(){
			$opt=get_option($this->db_options_name);
			$opt['version']=$this->ver;
			update_option($this->db_options_name,$opt);
		}
		function install(){
			$options=array(
				"default"=>$this->default_gravatar_url,
				"size"=>"80",
				"version"=>$this->ver
				);
			add_option($this->db_options_name,$options);
		}
		/*
			show and operate the options page
		*/
		function admin_options_page_constructor(){
			$err_echo='';
			$options=get_option($this->db_options_name);
			if ($_SERVER['REQUEST_METHOD'] == 'POST') {
				$err_msg = '';

				if (!empty($_POST['g3_avatar_default'])) {
					$options['default']=trim($_POST['g3_avatar_default']);
				} else {
					$err_msg .= "<b>ERROR:</b> Please provide a default avatar URL.<br />";
				}

				if (!empty($_POST['g3_avatar_size']) && is_numeric($_POST['g3_avatar_size'])) {
					$options['size']=trim($_POST['g3_avatar_size']);
				} else {
					$err_msg .= "<b>ERROR:</b> Please provide a numerical value for the avatar size.";
				}
				update_option($this->db_options_name,$options);

				if ($err_msg != "") {
					$err_echo= "<div id=\"message\" class=\"error fade\"><p>".$err_msg."</p></div>";
				} else {
					$err_echo= "<div id=\"message\" class=\"updated fade\"><p><strong>Options saved!</strong></p></div>";
				}
			}
			include ("options_form.php");
		}
		/*
			User interface functions.
		*/
		function display(){
			global $comment;
			$options=get_option($this->db_options_name);
			$gravatar_url=$this->compose_gravatar_address($comment->comment_author_email,$options['size'],$options['default']);
			$title=$comment->comment_author;
			return "<img class='g3_avatar' src='{$gravatar_url}' alt='{$this->alt}' title='$title' />";
		}
		function compose_gravatar_address($email,$size='',$default=''){
			$gravatar_id=md5($email);
			$options=get_option($this->db_options_name);

			if (trim($default)==''){
				$default=($options && empty($options['default']))?$this->default_gravatar_url:$options['default'];
			}
			$default=urlencode($default);

			if (trim($size)==''){
				$default=($options && empty($options['size']))?$this->default_gravatar_size:$options['size'];
			}
			return "http://www.gravatar.com/avatar.php?gravatar_id={$gravatar_id}&amp;size={$size}&amp;default={$default}?size={$size}";
		}
	}
	global $g3_avatar_o;
	$g3_avatar_o=new G3Avatar();
	register_activation_hook(__FILE__,array(&$g3_avatar_o,'activate'));


	/*
		use these functions!
	*/
	function G3Avatar_display($return=false){
		global $g3_avatar_o;
		$avt=$g3_avatar_o->display();
		if ($return){
			return $avt;
		}else{
			echo $avt;
		}
	}
	function G3Avatar_compose($email,$size='',$default='',$return=true){
		global $g3_avatar_o;
		$avt=$g3_avatar_o->compose_gravatar_address($email,$size,$default);
		if ($return){
			return $avt;
		}else{
			echo $avt;
		}
	}
}

?>